==> academy-admin-web-2.0.0-sources.jar: com/ptteng/academy/admin/util/CommonUtil.java <==
package com.ptteng.academy.admin.util;

import com.gemantic.common.util.PasswordUtils;

import java.util.*;

/**
 * Created by liangxj on 2016/12/16.
 */
public class CommonUtil {


    /**
     * 获取随机字母数字组合
     *
     * @param length
     *            字符串长度
     *@param end 生成字符串个数 end - start+1=count
     *
     * @return
     */
    public static Map<String,List<String>> generatePwdList(Integer length,Integer start,Integer end) {
        Random random = new Random();
        Map<String,List<String>> map = new HashMap<>();
        List<String> md5PwdList = new ArrayList<>();
        List<String> pwdList = new ArrayList<>();
        for(int j=start-1;j<end-1;j++){
            String str = "";


            for (int i = 0; i < length; i++) {
                if(i==length-length){
                    String num1= String.valueOf(random.nextInt(10));
                    str += num1;

                }else if(i==length-6){
                    int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                    char letter1 = (char) (choice + random.nextInt(26));
                    str += letter1;


                }else if(i==length-4){
                    String num2 = String.valueOf(random.nextInt(10));
                    str += num2;

                }else if(i==length-2){
                    int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                    char letter2 = (char) (choice + random.nextInt(26));
                    str += letter2;

                }else{
                    boolean b = random.nextBoolean();
                    if (b) { // 字符串
                        int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                        char letter3 = (char) (choice + random.nextInt(26));
                        str += letter3;

                    } else { // 数字
                        String num3 = String.valueOf(random.nextInt(10));
                        str += num3;


                    }
                }

            }
            // log.info(" str = "+str);
            String upperStr = str.toUpperCase();
            //log.info("  upperStr =" + upperStr);
            pwdList.add(str);
            str =  PasswordUtils.encode(upperStr);
            md5PwdList.add(str);

        }
        map.put("1",pwdList);
        map.put("2", md5PwdList);

        return map;
    }


    public static  String getPwdStr(int length) {
        Random random = new Random();
        String str = "";

        for (int i = 0; i < length; i++) {
            if (i == length - length) {
                String num1 = String.valueOf(random.nextInt(10));
                str += num1;

            } else if (i == length - 6) {
                int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                char letter1 = (char) (choice + random.nextInt(26));
                str += letter1;


            } else if (i == length - 4) {
                String num2 = String.valueOf(random.nextInt(10));
                str += num2;

            } else if (i == length - 2) {
                int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                char letter2 = (char) (choice + random.nextInt(26));
                str += letter2;

            } else {
                boolean b = random.nextBoolean();
                if (b) { // 字符串
                    int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                    char letter3 = (char) (choice + random.nextInt(26));
                    str += letter3;

                } else { // 数字
                    String num3 = String.valueOf(random.nextInt(10));
                    str += num3;


                }
            }


        }
        return str;
        }


}

==> academy-admin-web-2.0.3-sources.jar: com/ptteng/academy/admin/util/CommonUtil.java <==
package com.ptteng.academy.admin.util;

import com.gemantic.common.util.PasswordUtils;

import java.util.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Created by liangxj on 2016/12/16.
 */
public class CommonUtil {
    private static final Log log = LogFactory.getLog(CommonUtil.class);
    /**
     * 获取随机字母数字组合
     *
     * @param length
     *            字符串长度
     *@param end 生成字符串个数 end - start+1=count
     *
     * @return
     */
    public static Map<String,List<String>> generatePwdList(Integer length,Integer start,Integer end) {
        Random random = new Random();
        Map<String,List<String>> map = new HashMap<>();
        List<String> md5PwdList = new ArrayList<>();
        List<String> pwdList = new ArrayList<>();
        for(int j=start-1;j<end-1;j++){
            String str = "";


            for (int i = 0; i < length; i++) {
                if(i==length-length){
                    String num1= String.valueOf(random.nextInt(10));
                    str += num1;

                }else if(i==length-6){
                    int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                    char letter1 = (char) (choice + random.nextInt(26));
                    str += letter1;


                }else if(i==length-4){
                    String num2 = String.valueOf(random.nextInt(10));
                    str += num2;

                }else if(i==length-2){
                    int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                    char letter2 = (char) (choice + random.nextInt(26));
                    str += letter2;

                }else{
                    boolean b = random.nextBoolean();
                    if (b) { // 字符串
                        int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                        char letter3 = (char) (choice + random.nextInt(26));
                        str += letter3;

                    } else { // 数字
                        String num3 = String.valueOf(random.nextInt(10));
                        str += num3;


                    }
                }

            }
            // log.info(" str = "+str);
            String upperStr = str.toUpperCase();
            //log.info("  upperStr =" + upperStr);
            pwdList.add(str);
            str =  PasswordUtils.encode(upperStr);
            md5PwdList.add(str);

        }
        map.put("1",pwdList);
        map.put("2", md5PwdList);

        return map;
    }


    public static  String getPwdStr(int length) {
        Random random = new Random();
        String str = "";

        for (int i = 0; i < length; i++) {
            if (i == length - length) {
                String num1 = String.valueOf(random.nextInt(10));
                str += num1;

            } else if (i == length - 6) {
                int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                char letter1 = (char) (choice + random.nextInt(26));
                str += letter1;


            } else if (i == length - 4) {
                String num2 = String.valueOf(random.nextInt(10));
                str += num2;

            } else if (i == length - 2) {
                int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                char letter2 = (char) (choice + random.nextInt(26));
                str += letter2;

            } else {
                boolean b = random.nextBoolean();
                if (b) { // 字符串
                    int choice = random.nextBoolean() ? 97 : 97;// 取得65大写字母还是97小写字母
                    char letter3 = (char) (choice + random.nextInt(26));
                    str += letter3;

                } else { // 数字
                    String num3 = String.valueOf(random.nextInt(10));
                    str += num3;


                }
            }


        }
        return str;
        }

    public static boolean repeatValues (List<String> arr) {
        boolean result =false;
        log.info("repeatValues arr is "+arr + " size is "+ arr.size());
        Map<String,Integer>oArr =  new HashMap<>();
        for (String i:arr){
            oArr.put(i,1);
        }
        log.info("repeatValues oArr is "+oArr+ " size is "+ oArr.size());
        if (oArr.size() != arr.size()){
            result = true;
            log.info("There is a duplicate value");
        }
        return  result;
    }
}
